@@ -1,22 +1,20 @@
 package Job::Machine;
-
-our $VERSION = "0.13";
+BEGIN {
+  $Job::Machine::VERSION = '0.14';
+}
 
 1;
-__END__
+
+
 =pod
 
 =head1 NAME
 
-Job::Machine - Job queue handling
+Job::Machine
 
-=head1 DESCRIPTION
+=head1 VERSION
 
-A small, but versatile and efficient system for sending jobs to a message queue
-and communicating answers back to the sender.
-
-Job::Machine uses LISTEN / NOTIFY from PostgreSQL to send signals between
-workers and clients
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -45,6 +43,18 @@ Back at the Client:
       print $client->receive->{baz};
   }
 
+=head1 DESCRIPTION
+
+A small, but versatile and efficient system for sending jobs to a message queue
+and communicating answers back to the sender.
+
+Job::Machine uses LISTEN / NOTIFY from PostgreSQL to send signals between
+workers and clients
+
+=head1 NAME
+
+Job::Machine - Job queue handling
+
 =head1 SUPPORT
 
 Report tickets to http://rt.cpan.org/Job-Machine/
@@ -59,3 +69,19 @@ Copyright (C) 2009, Kaare Rasmussen
 
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Kaare Rasmussen <kaare at cpan dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Kaare Rasmussen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
