@@ -1,4 +1,7 @@
 package Job::Machine::Base;
+BEGIN {
+  $Job::Machine::Base::VERSION = '0.14';
+}
 
 use strict;
 use warnings;
@@ -35,7 +38,18 @@ sub log {
 }
 
 1;
-__END__
+
+
+=pod
+
+=head1 NAME
+
+Job::Machine::Base
+
+=head1 VERSION
+
+version 0.14
+
 =head1 NAME
 
 Job::Machine::Base - Base class both for Client and Worker Classes
@@ -82,4 +96,20 @@ Copyright (C) 2010, Kaare Rasmussen
 This module is free software; you can redistribute it or modify it
 under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
+
+=head1 AUTHOR
+
+Kaare Rasmussen <kaare at cpan dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Kaare Rasmussen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
